Changes
=======

0.0.8 (2016-09-11)

* Ensure only modified files be parsed while process the second time

0.0.7 (2016-08-26)

* Enabled fixers : collections, memoryview, printfunction, unittest
* Fixed lib3to2 don't write back
* Added helper functions : process_packages, process_requirements
